function [] = makeOrPlayMovie()
% GET DATA FROM JSim FILE
fid = fopen('moon.dat','r');
MyData = fscanf(fid,'%g');
imovie=MyData(1);
iframe=MyData(2);
nframe=MyData(3);
% EITHER JUST SHOW THE LAST MOVIE
if(imovie>1.5)
    figure('position',[100 100 660 560]);
    axis off;
    G=aviread('example.avi')
    movie(G,5,5);
    % OR MAKE A NEW MOVIE
else
    % MAKING A NEW MOVIE, GET REST OF DATA
    nx=MyData(3+1);
    ny=MyData(3+2);
    nt=MyData(3+3);
    if(nframe>nt)
        nframe = nt-1
    end
    rc=MyData(3+4); % rc used to mark plasma-tissue boundary in plot
    x=linspace(0,0,nx);
    y=linspace(0,0,ny);
    t=linspace(0,0,nt);

    for ix=1:nx
        x(ix)=MyData(7+ix);
    end
    for iy=1:ny
        y(iy)=MyData(7+nx+iy);
    end
    for it=1:nt
        t(it)=MyData(7+nx+ny+it);
    end

    A = zeros(ny,nx,nt);
    for it = 1:nt
        for iy=1:ny
            for ix = 1:nx
                ind=ix+(iy-1)*nx+(it-1)*nx*ny+(7+nx+ny+nt);
                A(iy,ix,it)=MyData(ind);
            end
        end

    end
    % PLOT later points less frequently
    % (early time linear, plot sequential frames
    % (later time logarithmic, plot interpolated frames
    % i.e.
    % DATA TIME
    % . . . . . . . . . . . . . . . . . . . . . . . . . . .
    % PLOT TIME
    % . . . . . .  .   .    .     .      .       .        .
    % <-linear- ><--------------logarithmic--------------->
    if(iframe>1.5)
        tlog=linspace(0,0,nframe);
        tlog(1)=t(1);
        dt=log(t(nt))-log(t(2));
        for i=2:nframe
            tlog(i)=exp(log(t(2))+(i-1.0)/(nframe-1.0)*dt);
            if(tlog(i)<t(i))
                tlog(i)=t(i); %replace log time calc with linear time
            end
        end
        tlog(nframe)=tlog(nframe)-.0001;

        [Y, X, T] = meshgrid(x,y,t);

        [BY, BX, BT] = meshgrid(x,y,tlog);

        B=interp3(Y,X,T,A,BY,BX,BT);
        A=B;
        t=tlog;
        nt = nframe;
        Y=BY;
        X=BX;
        T=BT;
    end
    % FIND MAXIMUM OUTFLOW CONCENTRATION TO SCALE LOWER PLOT
    Cout = linspace(0,0,nt);
    Coutmax=-1;
    for it=1:nt
        Cout(it) = A(1,nx,it);
        if(Cout(it)>Coutmax)
            Coutmax=Cout(it);
        end
    end
    Coutmax=Coutmax*1.15;

    [COMX COMY] = CenterOfMass(A,x,y,t);
    [COM2X COM2Y] = CenterOfMass2(A,x,y,t);
    [COMXc COMYc] = CenterOfMass3(A,x,y,t,rc);
    clf
    [X,Y]=meshgrid(x,y);
    c=colormap('gray');
    % REVISE COLOR MAP TO GO FROM LIGHT GREEN TO DARK GREEN (BLACK)
    % TO MATCH JSIM GREEN CONTOUR COLOR SCHEME
    for i=1:64
        c(i,1)=0.05+0.65*(i-1)/63;
        c(i,2)=(0.05+0.65*(i-1)/63)^0.25;
        c(i,3)=0.05+0.65*(i-1)/63;
    end
    colormap(c);
    beta=-0.7;
    brighten(beta);
    x1=linspace(x(1),x(nx),101);
    y1=linspace(y(1),y(ny),101);
    [X2 Y2] = meshgrid(x1,y1);
    % MAKE MOVIE
    mov = avifile('example.avi');
    % FOR A SEQUENCE OF TIMES
    for it=1:nt
        clf;
        hold off;
        % UPPER PLOT
        subplot(2,1,1);
        hold on;
        axis([x(1) x(nx) y(1) y(ny) ]);
        hold on
        set(gca,'nextplot','replacechildren');
        Z=A(:,:,it);
        Z2 = interp2(X,Y,Z,X2,Y2,'cubic');
        [C,h]= contourf(X2,Y2,Z2,11,'edgecolor','none') ;
        hold on;
        %clabel(C,h,v)
        hold on;
        line=0*linspace(x(1),x(nx),101)+rc;
        % DRAW PLASMA CELL BOUNDARY
        plot(x1,line,'k-');
        % ANNOTATE TIME IN MAGENTA IN UPPER LEFT CORNER OF PLOT
        txtcolor=[1 0 1];
        titl = sprintf('Time = %6.2f',t(it));
        text(1,18,titl,'FontSize',12,'FontWeight','bold','Color',txtcolor);
        hold on;
        % Center of Mass using radial volumes
        X1 = [COMX(1:it)  ];
        Y1 = [COMY(1:it)  ];
        % BLUE-WHITE CIRCLES CENTER OF MASS INCLUDING CAPILLARY
        plot(X1,Y1,'-bo', ...
            'MarkerSize',4, ...
            'MarkerFaceColor',[ 1.0 1.0 1.0 ] );
        hold on;
        % RED-WHITE SQUARES CENTER OF MASS EXCLUDING CAPILARY
        in=1;
        for n=it:-1:1
            if(COMYc(n)>rc)
                in=n;
            end
        end
        X1 = [COMXc(in:it)  ];
        Y1 = [COMYc(in:it)  ];
        plot(X1,Y1,'-rs', ...
            'MarkerSize',4, ...
            'MarkerFaceColor',[ 1.0 1.0 1.0 ] );
        title('Concentration');
        hold on;
        xlabel('Axial Distance, \mum');
        hold on;
        ylabel('Radial Distance, \mum');
        hold on;
        % LOWER PLOT OF OUTFLOW
        subplot(2,1,2)
        hold on;
        vxr=t(nt)+0.0001;
        axis( [t(1) vxr 0 Coutmax]);
        hold on;

        plot(t(1:it),Cout(1:it),'-ko');

        hold on;
        ylabel('Concentration, mM');
        hold on;
        xlabel('Time, sec');
        hold on;
        title('Outflow');
        hold on;

        F = getframe(gcf);
        mov = addframe(mov,F);

    end

    mov=close(mov);

    hold off;
    figure('position',[100 100 660 520]);
    axis off;

    %SHOW MOVIE TWICE
    G = aviread('example.avi');
    movie(G,2,5);
end
end